← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] ~cjwatson/launchpad:rename-code-import-slaves into launchpad:master

 

Colin Watson has proposed merging ~cjwatson/launchpad:rename-code-import-slaves into launchpad:master.

Commit message:
Talk about code import workers rather than slaves

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)

For more details, see:
https://code.launchpad.net/~cjwatson/launchpad/+git/launchpad/+merge/409525
-- 
Your team Launchpad code reviewers is requested to review the proposed merge of ~cjwatson/launchpad:rename-code-import-slaves into launchpad:master.
diff --git a/lib/lp/code/doc/codeimport-event.txt b/lib/lp/code/doc/codeimport-event.txt
index 92bf3c2..d15e6f5 100644
--- a/lib/lp/code/doc/codeimport-event.txt
+++ b/lib/lp/code/doc/codeimport-event.txt
@@ -488,7 +488,7 @@ updated their heartbeat fields recently enough.  When it does this, a
 RECLAIM event records the details of what happened.  The 'newReclaim'
 method takes as parameters the code import, the machine the job was
 running on and the id of the removed code import job row (to make
-finding the log files on the import slave easier).
+finding the log files on the import worker easier).
 
     >>> job_id = 42 # Arbitrary choice.
 
diff --git a/lib/lp/code/doc/xmlrpc-codeimport-scheduler.txt b/lib/lp/code/doc/xmlrpc-codeimport-scheduler.txt
index 117e87a..e60b0d7 100644
--- a/lib/lp/code/doc/xmlrpc-codeimport-scheduler.txt
+++ b/lib/lp/code/doc/xmlrpc-codeimport-scheduler.txt
@@ -2,7 +2,7 @@ The CodeImportScheduler
 =======================
 
 The code import scheduler is an XMLRPC service that provides (ids of)
-CodeImportJobs for code import slaves to run.  It is available as the
+CodeImportJobs for code import workers to run.  It is available as the
 codeimportscheduler attribute of our private XMLRPC instance.
 
     >>> from lp.code.interfaces.codeimportscheduler import (
@@ -31,7 +31,7 @@ XML-RPC API:
 
 The ICodeImportScheduler interface defines a single method,
 getJobForMachine(), that returns the id of the job that the code
-import slave should next run.
+import worker should next run.
 
     >>> codeimportscheduler_api.getJobForMachine('bazaar-importer', 2)
     1
diff --git a/lib/lp/code/interfaces/codeimportscheduler.py b/lib/lp/code/interfaces/codeimportscheduler.py
index e0d646e..fbbb938 100644
--- a/lib/lp/code/interfaces/codeimportscheduler.py
+++ b/lib/lp/code/interfaces/codeimportscheduler.py
@@ -23,12 +23,12 @@ class ICodeImportScheduler(Interface):
     """The code import scheduler.
 
     The code import scheduler is responsible for allocating import jobs to
-    machines.  Code import slave machines call the getJobForMachine() method
-    when they need more work to do.
+    machines.  Code import worker machines call the getJobForMachine()
+    method when they need more work to do.
     """
 
     def getJobForMachine(hostname, worker_limit):
         """Get a job to run on the slave 'hostname'.
 
         This method selects the most appropriate job for the machine,
         mark it as having started on said machine and return its id,
@@ -23,12 +23,12 @@ class ICodeImportScheduler(Interface):
 
     def getJobForMachine(hostname, worker_limit):
-        """Get a job to run on the slave 'hostname'.
+        """Get a job to run on the worker 'hostname'.
 
         This method selects the most appropriate job for the machine,